@@ -6,7 +6,7 @@ import getpass
 import sys
 
 import paramiko
-from nose.tools import with_setup, ok_
+from nose.tools import with_setup, raises, ok_
 from fudge import (Fake, clear_calls, clear_expectations, patch_object, verify,
     with_patched_object, patched_context, with_fakes)
 
@@ -14,9 +14,9 @@ from fabric.context_managers import settings, hide, show
 from fabric.network import (HostConnectionCache, join_host_strings, normalize,
     denormalize)
 from fabric.io import output_loop
-import fabric.network # So I can call patch_object correctly. Sigh.
+import fabric.network  # So I can call patch_object correctly. Sigh.
 from fabric.state import env, output, _get_system_username
-from fabric.operations import run, sudo
+from fabric.operations import run, sudo, prompt
 
 from utils import *
 from server import (server, PORT, RESPONSES, PASSWORDS, CLIENT_PRIVKEY, USER,
@@ -95,14 +95,12 @@ class TestNetwork(FabricTest):
                 'localhost', username + '@localhost:22'),
         ):
             eq_.description = "Host-string denormalization: %s" % description
-            yield eq_, denormalize(string1), denormalize(string2) 
+            yield eq_, denormalize(string1), denormalize(string2)
             del eq_.description
 
-
     #
     # Connection caching
     #
-
     @staticmethod
     @with_fakes
     def check_connection_calls(host_strings, num_calls):
@@ -136,7 +134,6 @@ class TestNetwork(FabricTest):
             TestNetwork.check_connection_calls.description = description
             yield TestNetwork.check_connection_calls, host_strings, num_calls
 
-
     def test_connection_cache_deletion(self):
         """
         HostConnectionCache should delete correctly w/ non-full keys
@@ -159,13 +156,11 @@ class TestNetwork(FabricTest):
     #
     # Connection loop flow
     #
-
     @server()
     def test_saved_authentication_returns_client_object(self):
         cache = HostConnectionCache()
         assert isinstance(cache[env.host_string], paramiko.SSHClient)
 
-
     @server()
     @with_fakes
     def test_prompts_for_password_without_good_authentication(self):
@@ -175,6 +170,42 @@ class TestNetwork(FabricTest):
             cache[env.host_string]
 
 
+    @raises(SystemExit)
+    @with_patched_object(output, 'aborts', False)
+    def test_aborts_on_prompt_with_abort_on_prompt(self):
+        """
+        abort_on_prompt=True should abort when prompt() is used
+        """
+        env.abort_on_prompts = True
+        prompt("This will abort")
+
+
+    @server()
+    @raises(SystemExit)
+    @with_patched_object(output, 'aborts', False)
+    def test_aborts_on_password_prompt_with_abort_on_prompt(self):
+        """
+        abort_on_prompt=True should abort when password prompts occur
+        """
+        env.password = None
+        env.abort_on_prompts = True
+        with password_response(PASSWORDS[env.user], times_called=1):
+            cache = HostConnectionCache()
+            cache[env.host_string]
+
+
+    @mock_streams('stdout')
+    @server()
+    def test_does_not_abort_with_password_and_host_with_abort_on_prompt(self):
+        """
+        abort_on_prompt=True should not abort if no prompts are needed
+        """
+        env.abort_on_prompts = True
+        env.password = PASSWORDS[env.user]
+        # env.host_string is automatically filled in when using server()
+        run("ls /simple")
+
+
     @mock_streams('stdout')
     @server()
     def test_trailing_newline_line_drop(self):
@@ -195,7 +226,6 @@ class TestNetwork(FabricTest):
             # Also test that the captured value matches, too.
             eq_(output_string, result)
 
-
     @server()
     def test_sudo_prompt_kills_capturing(self):
         """
@@ -205,7 +235,6 @@ class TestNetwork(FabricTest):
         with hide('everything'):
             eq_(sudo(cmd), RESPONSES[cmd])
 
-
     @server()
     def test_password_memory_on_user_switch(self):
         """
@@ -242,7 +271,6 @@ class TestNetwork(FabricTest):
             ):
                 sudo("ls /simple")
 
-
     @mock_streams('stderr')
     @server()
     def test_password_prompt_displays_host_string(self):
@@ -257,7 +285,6 @@ class TestNetwork(FabricTest):
         regex = r'^\[%s\] Login password: ' % env.host_string
         assert_contains(regex, sys.stderr.getvalue())
 
-
     @mock_streams('stderr')
     @server(pubkeys=True)
     def test_passphrase_prompt_displays_host_string(self):
@@ -273,7 +300,6 @@ class TestNetwork(FabricTest):
         regex = r'^\[%s\] Login password: ' % env.host_string
         assert_contains(regex, sys.stderr.getvalue())
 
-
     def test_sudo_prompt_display_passthrough(self):
         """
         Sudo prompt should display (via passthrough) when stdout/stderr shown
@@ -318,7 +344,6 @@ class TestNetwork(FabricTest):
 [%(prefix)s] out: sudo password: """ % {'prefix': env.host_string}
         eq_(expected[1:], sys.stdall.getvalue())
 
-
     @mock_streams('both')
     @server(
         pubkeys=True,
@@ -351,7 +376,6 @@ class TestNetwork(FabricTest):
 """ % {'prefix': env.host_string}
         eq_(expected[1:], sys.stdall.getvalue())
 
-
     @mock_streams('both')
     @server(pubkeys=True, responses={'silent': '', 'normal': 'foo'})
     def test_silent_commands_should_not_have_blank_line(self):
@@ -384,7 +408,6 @@ class TestNetwork(FabricTest):
 """ % {'prefix': env.host_string}
         eq_(expected[1:], sys.stdall.getvalue())
 
-
     @mock_streams('both')
     @server(
         pubkeys=True,
@@ -413,7 +436,6 @@ class TestNetwork(FabricTest):
 """ % {'prefix': env.host_string}
         eq_(expected[1:], sys.stdall.getvalue())
 
-
     @mock_streams('both')
     @server(
         pubkeys=True,
